==> IO-K8s-1.000.tar.gz: IO-K8s-1.000/lib/IO/K8s/Api/Core/V1/VolumeMountStatus.pm <==
package IO::K8s::Api::Core::V1::VolumeMountStatus;
# ABSTRACT: VolumeMountStatus shows status of volume mounts.
our $VERSION = '1.000';
use IO::K8s::Resource;

k8s mountPath => Str, 'required';


k8s name => Str, 'required';


k8s readOnly => Bool;


k8s recursiveReadOnly => Str;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Core::V1::VolumeMountStatus - VolumeMountStatus shows status of volume mounts.

=head1 VERSION

version 1.000

=head2 mountPath

MountPath corresponds to the original VolumeMount.

=head2 name

Name corresponds to the name of the original VolumeMount.

=head2 readOnly

ReadOnly corresponds to the original VolumeMount.

=head2 recursiveReadOnly

RecursiveReadOnly must be set to Disabled, Enabled, or unspecified (for non-readonly mounts). An IfPossible value in the original VolumeMount must be translated to Disabled or Enabled, depending on the mount result.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartinez@capside.com> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by CAPSiDE.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

==> IO-K8s-1.001.tar.gz: IO-K8s-1.001/lib/IO/K8s/Api/Core/V1/VolumeMountStatus.pm <==
package IO::K8s::Api::Core::V1::VolumeMountStatus;
# ABSTRACT: VolumeMountStatus shows status of volume mounts.
our $VERSION = '1.001';
use IO::K8s::Resource;

k8s mountPath => Str, 'required';


k8s name => Str, 'required';


k8s readOnly => Bool;


k8s recursiveReadOnly => Str;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Core::V1::VolumeMountStatus - VolumeMountStatus shows status of volume mounts.

=head1 VERSION

version 1.001

=head2 mountPath

MountPath corresponds to the original VolumeMount.

=head2 name

Name corresponds to the name of the original VolumeMount.

=head2 readOnly

ReadOnly corresponds to the original VolumeMount.

=head2 recursiveReadOnly

RecursiveReadOnly must be set to Disabled, Enabled, or unspecified (for non-readonly mounts). An IfPossible value in the original VolumeMount must be translated to Disabled or Enabled, depending on the mount result.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
